@@ -1,7 +1,7 @@
 // -*- c++ -*-
 #ifndef _GLIBMM_ERROR_H
 #define _GLIBMM_ERROR_H
-/* $Id: error.h 336 2006-10-04 12:06:14Z murrayc $ */
+/* $Id: error.h 749 2008-12-10 14:23:33Z jjongsma $ */
 
 /* Copyright 2002 The gtkmm Development Team
  *
@@ -24,7 +24,7 @@
 extern "C" { typedef struct _GError GError; }
 #endif
 
-#include <glib/gquark.h>
+#include <glib.h>
 #include <glibmm/exception.h>
 #include <glibmmconfig.h> //For GLIBMM_EXCEPTIONS_ENABLED
 
